#include <Adafruit_Sensor.h>        // Includes the Adafruit Library for the BMP280 sensor
#include <Adafruit_BMP280.h>        // Includes the BMP280 sensor Library
#include <Wire.h>        // Includes the Wire Library for I2C for the BMP280 sensor
#include <SPI.h>        // Includes the SPI (Serial Peripheral Interface) Library for the BMP280 sensor
#define USE_ARDUINO_INTERRUPTS true    // Set-up low-level interrupts for most accurate BPM math.
#include <PulseSensorPlayground.h>     // Includes the PulseSensorPlayground Library for the heartbeat sensor  
#define BMP_SCK 13        // Defines the Adafruit SCK (Serial Clock Output) part of the BMP280 sensor
#define BMP_MISO 12        // Defines the Adafruit MISO (Master In Slave Out) part of the BMP280 sensor
#define BMP_MOSI 11        // Defines the Adafruit MOSI (Master Out Slave In) part of the BMP280 sensor
#define BMP_CS 10        // Defines the Adafruit CS (temperature) part of the BMP280 sensor

Adafruit_BMP280 bme;        // Calls the BMP280 sensor bme

PulseSensorPlayground pulseSensor;  // Creates an instance of the PulseSensorPlayground object called "pulseSensor"

const int PulseWire = 0;       // PulseSensor PURPLE WIRE connected to ANALOG PIN 0
int heartbeat = 0;        // Sets an integer to be changed to the the latest received BPM
const int liquidSensor = 1;       // PulseSensor YELLOW WIRE connected to ANALOG PIN 1

void setup() {
  Serial.begin(9600);       // Set the serial baud to 9600
  if (!bme.begin()) {       // Starts the bme to connect the BMP280 sensor
    while (1);
  }

  pulseSensor.analogInput(PulseWire);          // Reads the analog input from the heartbeat sensor

  if (pulseSensor.begin()) {       // Starts up the heartbeat sensor
  }
}

void loop() {
  if (pulseSensor.sawStartOfBeat()) {            // Constantly test to see if "a beat happened".
    heartbeat = pulseSensor.getBeatsPerMinute();  // Calls function on our pulseSensor object that returns BPM as an integer on "heartbeat"
  }

  Serial.print(heartbeat);            // Print the latest value of the heartbeat
  Serial.print("|");            // Put a break in between the sensor reads for readouts in the app
  Serial.print(analogRead(liquidSensor));            // Print the current value of the humidity sensor
  Serial.print("|");            // Put a break in between the sensor reads for readouts in the app
  Serial.print(bme.readTemperature());            // Print the current value of the temperature sensor
  Serial.println();            // Sends out the data to the app

  delay(5000);            // Set a 5 second delay in between the transmissions of data to the app for battery saving
}
